source commands.tcl

module PW -title "PWSCF GUI: module PW.x" -script {
    
    readfilter  ::pwscf::pwReadFilter
    writefilter ::pwscf::pwWriteFilter

    # ------------------------------------------------------------------------
    # devide the GUI on pages (each namelist on its own page)
    # ------------------------------------------------------------------------

    ########################################################################
    ##                                                                    ##
    ##                      &CONTROL NAMELIST                             ##
    ##                                                                    ##
    ########################################################################

    page controlPage -name "Control" {
	namelist control -name "CONTROL" {
	    optional {
		#-default  "'PWSCF sample input'"
		var title -label "Job Title (title):"

		var calculation {
		    -label     "Type of calculation (calculation):"
		    -widget    radiobox
		    -textvalue {
			"Self-Consistent-Field  <scf>"
			"Band structure calculation  <nscf>"
			"Phonon calculation  <phonon>"	
			"Ionic relaxation  <relax>"
			"Ionic relaxation with Variable-Cell  <vc-relax>"
			"Molecular dynamics  <md>"
			"Molecular dynamics with Variable-Cell  <vc-md>"
			"Nudged Elastic Band  <neb>"
                        "String Method Dynamics  <smd>"
			"Meta-dynamics  <metadyn>"
		    }
		    -value {
			'scf'
			'nscf'
			'phonon'
			'relax'
			'vc-relax'
			'md'
			'vc-md'
			'neb'
                        'smd'
			'metadyn'
		    }
		    -default "Self-Consistent-Field  <scf>"
		}
		
		var max_seconds {
		    -label    "Maximum CPU time \[in seconds\] (max_seconds):"
		    -validate posint
		}

		var restart_mode {
		    -label    "Restart mode (restart_mode):"
		    -widget   optionmenu
		    -textvalue {
			"from scratch  <from_scratch>"
			"from previous interrupted run  <restart>"
		    }
		    -value {
			'from_scratch'
			'restart'
		    }
		    -default  "from scratch  <from_scratch>"
		}

		var wf_collect {
		    -label     "Make a single restart file (wf_collect):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}

		separator -label "--- Directories/Files/Stdout ---"
		
		var outdir {
		    -label     "Temporary directory (outdir):"
		    -widget    entrydirselectquote
		    -validate  string
		}

		var wfcdir {
		    -label     "Temp. directory for files generated by each CPU (wfcdir):"
		    -widget    entrydirselectquote
		    -validate  string
		}

		var pseudo_dir \
		    -label    "Directory containing pseudopotential files (pseudo_dir:)" \
		    -widget   [list entrybutton "Directory ..." "::pwscf::pwSelectPseudoDir $this"] \
		    -validate  string

		var prefix -label "Prefix for I/O filenames (prefix):" -validate  string

		var lkpoint_dir {
		    -label "Store each k-point in its own subdirectory (lkpoint_dir):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}

		var disk_io {
		    -label    "Disk Input/Output (disk_io):"
		    -textvalue {
			high default low minimal
		    }
		    -value {
			'high' 'default' 'low' 'minimal'
		    }
		    -widget optionmenu
		}

		var verbosity {
		    -label     "Verbosity of output (verbosity):"
		    -widget    optionmenu
		    -textvalue {
			high
			default
			low
			minimal
		    }
		    -value {
			'high'
			'default'
			'low'
			'minimal'
		    }
		}

		var iprint {
		    -label   "Interval (in SCF iterations) for printing band energies (iprint):"
		    -widget   spinint
		    -validate nonnegint
		}

		separator -label "--- Ionic Minimization ---"

		#-text     "threshold on total energy for ionic minimization"
		var etot_conv_thr {
		    -label    "Convergence energy threshold \[in Ryd\] (etot_conv_thr):"
		    -validate fortranposreal
		}

		#-text     "Convergence threshold on forces for ionic minimization"
		var forc_conv_thr {
		    -label    "Convergence force threshold \[in Ryd/Bohr\] (forc_conv_thr):"
		    -validate fortranposreal
		}

		separator -label "--- Miscellaneous control parameters ---"
		
		var nstep {
		    -label    "Number of ionic steps (nstep):"
		    -widget   spinint
		    -validate posint
		}

		var tstress {
		    -label    "Calculate stress (tstress):"
		    -widget   radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}

		var tprnfor {
		    -label     "Calculate forces (tprnfor):"
		    -variable  tprnfor
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}
		
		var dt {
		    -label     "Molecular-Dynamics time step (dt):"
		    -validate  fortranposreal
		}

		var tefield {
		    -label     "Add a sawlike potential to bare ionic potential (tefield):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}

		var dipfield {
		    -label     "Add a dipole correction to bare ionic potential (dipfield):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}

		var lelfield {
		    -label     "Add a homogeneous finite electric field (lelfield):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}

		separator -label "--- Berry phase ---"

		var lberry {
		    -label     "Calculate Berry phase (lberry):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}
		var gdir   {
		    -label    "Direction of the k-point strings (gdir):"
		    -widget   optionmenu
		    -textvalue {
			"along 1st reciprocal vector"
			"along 2nd reciprocal vector"
			"along 3rd reciprocal vector"
		    }
		    -value { 1 2 3 }		
		}
		var nppstr {
		    -label "Num. of k-points along each symmetry-reduced string (nppstr):"
		    -validate posint
		}
		var nberrycyc {
		    -label "Num. of iterations for lelfield [see help] (nberrycyc):"
		    -validate posint
		}
	    }
	}
    }
    

    ########################################################################
    ##                                                                    ##
    ##                      &SYSTEM NAMELIST                              ##
    ##                                                                    ##
    ########################################################################

    page systemPage -name "System" {

	# ----------------------------------------------------
	# REQUIRED variables
	# ----------------------------------------------------

	namelist system -name "SYSTEM" {	    
	    required {
		#
		# WARNING: if you change the strings among the possible
		#          ibrav values, then search the "tracevar ibrav"
		#          section in the file pwscf-special.tcl and change
		#          there the strings to match EXACTLY with the 
		#          ones defined here !!!
		#	    
		var ibrav {
		    -label     "Braivas lattice index (ibrav):"
		    -fmt       %d
		    -widget    combobox
		    -textvalue {
			"Free lattice"
			"Cubic P (sc)"
			"Cubic F (fcc)"
			"Cubic I (bcc)"
			"Hexagonal and Trigonal P"
			"Trigonal R"
			"Tetragonal P (st)"
			"Tetragonal I (bct)"
			"Orthorhombic P"
			"Orthorhombic base-centered(bco)"
			"Orthorhombic face-centered"
			"Orthorhombic body-centered"
			"Monoclinic P"
			"Monoclinic base-centered"
			"Triclinic P"
		    }
		    -value {0 1 2 3 4 5 6 7 8 9 10 11 12 13 14}
		}

		group lattice_spec -name "Lattice specification:" -decor normal {
		    auxilvar how_lattice {
			-label     "How to specify lattice:"
			-value     {celldm abc}
			-textvalue {"by celldm()" "by A,B,C,cosAB,cosAC,cosBC"}
			-widget    radiobox
		    }
		    
		    dimension celldm {
			-label "Crystallographic constants (celldm)"
			-validate  fortranreal
			-start 1
			-end   6
		    }
		    
		    group abc {
			packwidgets left
			var A -label "A:" -validate fortranposreal
			var B -label "B:" -validate fortranposreal
			var C -label "C:" -validate fortranposreal
		    }
		    group cosABC {
			packwidgets left
			var cosAB -label "cosAB:" -validate fortranreal		    
			var cosAC -label "cosAC:" -validate fortranreal
			var cosBC -label "cosBC:" -validate fortranreal		    
		    }
		}

		var nat {
		    -label    "Number of atoms in the unit cell (nat):"
		    -fmt       %d
		    -default   1
		    -widget    spinint
		    -validate  posint
		}
		
		var ntyp {
		    -label    "Number of types of atoms in the unit cell (ntyp):"
		    -fmt      %d
		    -default  1
		    -widget   spinint  
		    -validate posint
		}		
		
		var ecutwfc {
		    -label    "Kinetic energy cutoff for WAVEFUNCTION \[in Ryd\] (ecutwfc):"
		    -validate fortranposreal
		}

		var ecutrho {
		    -label    "Kinetic energy cuttof for DENSITY \[in Ryd\] (ecutrho):"
		    -validate fortranposreal
		}
	    }

	    # ----------------------------------------------------
	    # OPTIONAL variables
	    # ----------------------------------------------------

	    optional {		
		var nosym {
		    -label     "Do not use the symmetry (nosym):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}
		
		var nosym_evc {
		    -label     "Do not use the symmetry except for the k-points (nosym_evc):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}
		
		var noinv { 
		    -label     "Disable time reversal symmetry in k-point generation (noinv):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}

		var force_symmorphic { 
		    -label     "Force the symmetry group to be symmorphic (force_symmorphic):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}

		var nbnd {
		    -label    "Number of electronic states (nbnd):"
		    -widget   spinint
		    -validate posint
		    -fmt      %d
		}

		var nelec {
		    -label    "Number of electrons in unit cell (nelec):"
		    -widget   spinint
		    -validate posint
		    -fmt      %d
		}

		var tot_charge {
		    -label    "Total system charge (tot_charge):"
		    -validate fortranreal
		    -fmt      %f
		}

		var input_dft -label    "Exchange-correlation functional (input_dft):"

		separator -label "--- Occupations ---"

		var occupations {
		    -label    "Occupation of states (occupations):"
		    -widget   optionmenu
		    -textvalue {
			smearing tetrahedra fixed "read from input"
		    }
		    -value {
			'smearing' 'tetrahedra' 'fixed' 'from_input'
		    }
		}

		var degauss {
		    -label    "Gaussian spreading for BZ integration \[in Ryd\] (degauss):"
		    -validate fortrannonnegreal
		}

		var smearing {
		    -label    "Type of spreading/smearing (smearing):"
		    -textvalue {
			"first order interpolation in Methfessel-Paxton spreading  <methfessel-paxton>"
			"ordinary Gaussian spreading  <gaussian>"
			"Marzari-Vanderbilt cold smearing  <marzari-vanderbilt>"
			"Fermi-Dirac smearing  <fermi-dirac>"
		    }
		    -value  {
			'methfessel-paxton'
			'gaussian'
			'marzari-vanderbilt'
			'fermi-dirac'
		    }
		    -widget optionmenu
		}

		separator -label "--- Spin polarization ---"

		var nspin {
		    -label     "Perform spin-polarized calculation (nspin):"
		    -textvalue {No Yes}
		    -value     {1  2}
		    -widget    radiobox
		}
		
		group spin_polarization -decor none {
 
		    dimension starting_magnetization {
			-label "Starting magnetization (starting_magnetization):"
			-text  "Specify starting magnetization (between -1 and 1) for each \"magnetic\" species"
			-validate  fortranreal
			-start 1 -end 1
		    }
		    
		    var multiplicity {
			-label     "Spin multiplicity (multiplicity):"
			-validate  posint
			-widget    spinint
		    }
		    
		    var nelup {
			-label    "Number of spin-up electrons:"
			-validate fortrannonnegreal
		    }
		    
		    var neldw {
			-label    "Number of spin-down electrons:"
			-validate fortrannonnegreal
		    }

		    var tot_magnetization {
			-label     "Total magnetization, nelup - neldw (tot_magnetization):"
			-validate  posint
			-widget    spinint
		    }
		}
		
		# insert here ...

		separator -label "--- Noncolinear calculation ---"

		var noncolin {
		    -label     "Perform noncolinear calculation (noncolin):"
		    -textvalue {No Yes}
		    -value     {.false. .true.}
		    -widget    radiobox
		}		

		group noncolin_group {
		    dimension angle1 {
			-label "Starting magnetization direction (angle1) :"
			-text  "Specify starting magnetization direction for each \"magnetic\" species"
			-validate  fortranreal
			-start 1 -end 1
		    }

		    dimension angle2 {
			-label "Starting magnetization direction (angle2):"
			-text  "Specify starting magnetization direction for each \"magnetic\" species"
			-validate  fortranreal
			-start 1 -end 1
		    }

		    var lspinorb {
			-label     "Allow the use of a pseudopotential with spin-orbit (lspinorb):"
			-textvalue {No Yes}
			-value     {.false.  .true.}
			-widget    radiobox
		    }
		}
		
		separator -label "--- Constrained/Fixed magnetization ---"

		group constrained_magnetization_group {
		    
		    var constrained_magnetization {
			-label     "Constrained magnetic calculation (constrained_magnetization):"
			-textvalue {
			    "no constrain  <none>" 
			    "constrain TOTAL magnetization  <total>"
			    "constrain ATOMIC magnetization  <atomic>"
			    "constrain magnetization to \"ATOMIC DIRECTION\"  <atomic direction>"
			    "constrain the direction of total magnetization  <total directioin>"
			}
			-value     {'none' 'total' 'atomic' {'atomic direction'} {'total direction'}}
			-widget    optionmenu
		    }
		    
		    dimension fixed_magnetization {
			-label "Fixed total magnetization"
			-start 1 -end 3
			-validate fortranreal
		    }
		    
#		    dimension B_field {
#			-label "Add a fixed magnetic field (B_field):"
#			-start 1 -end 3
#			-validate fortranreal
#		    }
		    
		    var lambda {
			-label "Lamda parameter for constrained magnetization (lambda):"
			-validate fortranreal
		    }
		    
		    var report {
			-label "Interval (in iterations) for printing atomic magnetic moments (report):"
			-validate posint
		    }
		}

		separator -label "--- LDA + U parameters ---"
	       
		var lda_plus_u {
		    -label     "Perform LDA + U calculation (lda_plus_u):"
		    -textvalue {No Yes}
		    -value     {.false.  .true.}
		    -widget    radiobox
		}
		    
		group hubbard -name Hubbard {
		    dimension Hubbard_U {
			-label     "Hubbarb U (Hubbard_U):"
			-validate  fortranreal
			-start 1 -end 1
		    }
		    
		    dimension Hubbard_alpha {
			-label     "Hubbard alpha (Hubbard_alpha):"
			-validate  fortranreal
			-start 1 -end 1
		    }

		    var U_projection_type {
			-label  "Type of projector on localized orbital (U_projector_type):"
			-widget optionmenu
			-textvalue {
			    "use atomic wfc's (as they are) to build the projector  <atomic>"
			    "use Lowdin orthogonalized atomic wfc's  <ortho-atomic>"
			    "use Lowdin normalization of atomic wfc  <norm-atomic>"
			    "use the information from file \"prefix\".atwfc  <file>"
			}
			-value {
			    'atomic'
			    'ortho-atomic'
			    'norm-atomic'
			    'file'
			}
		    }		
		}

		separator -label "--- Variable cell parameters ---"

		group vc_md -name VC-MD {		    
		    var ecfixed {
			-label     "ecfixed:"
			-validate  fortranreal
		    }
		    var qcutz {
			-label     "qcutz:"
			-validate  fortranreal
		    }
		    var q2sigma {
			-label     "q2sigma:"
			-validate  fortranreal
		    }
		}	
		
		separator -label "--- Saw-like potential parameters ---"

		group tefield_group -name TeField {
		    var edir {
			-label    "Direction of electric field (edir)"
			-widget   optionmenu
			-textvalue {
			    "along 1st reciprocal vector"
			    "along 2nd reciprocal vector"
			    "along 3rd reciprocal vector"
			}
			-value { 1 2 3 }
		    }
		    
		    var emaxpos {
			-text     "Position of maximum of sawlike potential within the unit cell"
			-label    "Position of maximum (emaxpos):"
			-validate fortranreal
		    }

		    var eopreg {
			-text     "Part of the unit cell where the sawlike potential decreases"
			-label    "Where the sawlike potential decreases (eopreg):"
			-validate fortranreal
		    }

		    var eamp -label "Amplitude of the electric field \[in a.u.\] (eamp):"
		}

		separator -label "--- Low-dimensional calculation ---"

		var assume_isolated {
		    -label "Compute Makov-Payne correction to the total energy (assume_isolated):"
		    -textvalue {Yes No}
		    -value     {.true. .false.}
		    -widget    radiobox
		}	
	    
		var do_ee {
		    -label "Embed the system in electrostatic environment \[see EE namelist\] (do_ee):"
		    -textvalue {Yes No}
		    -value     {.true. .false.}
		    -widget    radiobox
		}	
	    	       
		separator -label "--- Semi-empirical van der Waals ---"

		group vdW -name vdW {
		    var london {
			-label "Compute the semi-empirical dispersion term \[aka DFT-D\] (london):"
			-textvalue {Yes No}
			-value     {.true. .false.}
			-widget    radiobox
		    }  

		    var london_s6 -label "Global scaling parameter for DFT-D (london_s6):" -validate fortranposreal
		    var london_rcut -label "Cutoff radius for dispersion interactions \[in a.u.\] (london_rcut):" -validate fortranposreal
		}

		separator -label "--- FFT mesh (hard grid) for charge density ---"

		var nr1 -label "nr1:" -validate posint -widget spinint
		var nr2 -label "nr2:" -validate posint -widget spinint
		var nr3 -label "nr3:" -validate posint -widget spinint

		separator -label "--- FFT mesh (soft grid) for wavefunction ---"

		var nr1s -label "nr1s:" -validate posint -widget spinint
		var nr2s -label "nr2s:" -validate posint -widget spinint
		var nr3s -label "nr3s:" -validate posint -widget spinint
	    }
	}
    }

    ########################################################################
    ##                                                                    ##
    ##                      &ELECTRONS NAMELIST                           ##
    ##                                                                    ##
    ########################################################################

    page electronsPage -name "Electrons" {
	namelist electrons -name "ELECTRONS" {
	    optional {
		var electron_maxstep {
		    -label     "Max. \# of iterations in SCF step (electron_maxstep):"
		    -widget    spinint
		    -validate  posint
		    -fmt       %d
		}
		
		var conv_thr {
		    -label     "Convergence threshold for selfconsistency (conv_thr):"
		    -validate  fortranposreal
		}
	       
		var startingpot {
		    -label    "Type of starting potential (startingpot):"
		    -widget   optionmenu
		    -textvalue {
			"from atomic charge superposition  <atomic>"
			{from existing potential "prefix".pot file  <file>}
		    }
		    -value {'atomic' 'file'}
		}

		var startingwfc {
		    -label    "Type of starting wavefunctions (startingwfc):"
		    -widget   optionmenu
		    -textvalue {
			"from superposition of atomic orbitals  <atomic>"
			"from <atomic> + superimposed \"randomization\"  <atomic+random>"
			"from random wavefunctions  <random>"
			"from existing wavefunction file  <file>"
		    }
		    -value {'atomic' 'atomic+random' 'random' 'file'}
		}

		separator -label "--- SCF Mixing ---"

		var mixing_mode {
		    -label     "Mixing mode (mixing_mode):"
		    -textvalue {
			"charge density Broyden mixing  <plain>"
			"charge density Broyden mixing with simple Thomas-Fermi (TF) screening  <TF>"
			"charge density Broyden mixing with local-density-dependent TF screening  <local-TF>"
		    }
		    -value {
			'plain' 
			'TF'    
			'local-TF'
		    }
		    -widget optionmenu
		}

		var mixing_beta {
		    -label    "Mixing factor for self-consistency (mixing_beta):"
		    -validate  fortranposreal
		}

		var mixing_ndim {
		    -label    "Number of iterations used in mixing scheme (mixing_ndim):"
		    -widget   spinint
		    -validate posint
		    -fmt      %d
		}

		var mixing_fixed_ns {
		    -text     "For LDA+U only: ns = atomic density appearing in the Hubbard term"
		    -label    "Number of iterations with fixed ns (mixing_fixed_ns):" 
		    -widget   spinint
		    -validate posint
		    -fmt      %d
		}

		separator -label "--- Diagonalization ---"

		var diagonalization {
		    -label    "Type of diagonalization (diagonalization):"
		    -textvalue {
			"Davidson iterative diagonalization with overlap matrix  <david>"
			"Serial Davidson iterative diagonalization  <david-serial>"
			"Conjugate-gradient-like band-by-band diagonalization  <cg>"
		    }
		    -value {
			'david'
			'david-serial'
			'cg'
		    }
		    -widget optionmenu
		}

		var diago_thr_init {
		    -label "Convergence threshold for 1st iterative diagonalization (diago_thr_init):"
		    -validate fortranreal
		}

		var diago_full_acc {
		    -label "Diagonalize empty states as precise as occupied states (diago_full_acc):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }
		}
		
		var diago_cg_maxiter {
		    -text     "For CONJUGATE-GRADIENT DIAGONALIZATION only"
		    -label    "Max. \# of iterations (diago_cg_maxiter):"
		    -widget   spinint
		    -validate posint
		    -fmt      %d
		}
		
		separator -label "--- DAVIDSON diagonalization ---"

		var ortho_para {
		    -label "Number of processors to be used for the parallel subspace\ndiagonalization algorithm (ortho_para):"
		    -validate nonnegint
		}

		var diago_david_ndim {
		    -label    "Dimension of workspace (diago_david_ndim):"
		    -widget   spinint
		    -validate posint
		    -fmt      %d
		}

		#separator -label "--- DIIS diagonalization ---"
		#
		#group diis -name "DISS diagonalization" {
		#
		#    var diago_diis_ndim {
		#	-text     "For DIIS only only"
		#	-label    "Dimension of the reduced space (diago_diis_ndim):"
		#	-widget   spinint
		#	-validate posint
		#	-fmt      %d
		#    }
		#}

		separator -label "--- Finite electric field calculation ---"

		var efield {
		    -label    "The intensity of the electric field (efield):"
		    -validate fortranreal
		}

		separator -label "--- Ultrasoft pseudopotentials ---"
		
		var tqr {
		    -label "Use  real-space algorithm for augmentation charges (tqr):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }		
		}
	    }    
	}
    }

    ########################################################################
    ##                                                                    ##
    ##                      &IONS NAMELIST                                ##
    ##                                                                    ##
    ########################################################################

    page ionsPage -name "Ions" {	
	namelist ions -name "IONS" {
	    optional {
		# this should be modified as it is CASE dependent		
		var ion_dynamics {
		    -label "Type of ionic dynamics (ion_dynamics):"
		    -widget   optionmenu
		    -textvalue {
			"BFGS quasi-newton method for structural optimization  <bfgs>"
			"damped dynamics (quick-min Verlet) for structural optimization  <damp>"
			"Verlet algorithm for molecular dynamics  <verlet>"
			"over-damped Langevin dynamics  <langevin>"
                        "Beeman algorithm for variable cell damped dynamics  <damp>"
			"Beeman algorithm for variable cell MD  <beeman>"
		    }
		    -value {
			'bfgs' 
			'damp' 
			'verlet'
			'langevin'
                        'damp'
			'beeman'
		    }
		}

		var ion_positions {
		    -label "Which ion positions to use when restarting (ion_positions):"
		    -widget radiobox
		    -textvalue { 
			"from restart file"
			"from standard input"			
		    }
		    -value { 'default' 'from_input' }
		}
                
                var phase_space {
		    -label "Type of phase-space (phase_space):"
                    -textvalue {
			"The standard configuration space  <full>"
			"Coarse-grained phase-space defined by few order parameters  <coarse-grained>"
		    }
		    -value {
			'full' 'coarse-grained'
		    }
		    -widget optionmenu
                }

		var pot_extrapolation {
		    -text "Extrapolation for the potential"
		    -label "Type of extrapolation (pot_extrapolation):"
		    -textvalue {
			"no extrapolation  <none>"
			"extrapolate the potential as a sum of atomic-like orbitals  <atomic>"
			"extrapolate potential with first-order  formula  <first_order>"
			"extrapolate potential with second-order formula  <second_order>"
		    }
		    -value {
			'none' 'atomic' 'first_order' 'second_order'
		    }
		    -widget optionmenu
		}
                
		var wfc_extrapolation {
		    -text "Extrapolation for the wavefunctions"
		    -label "Type of extrapolation (wfc_extrapolation):"
		    -textvalue {
			"no extrapolation  <none>"
			"extrapolate wave-functions with first-order  formula  <first_order>"
			"extrapolate wave-functions with second-order formula  <second_order>"
		    }
		    -value {
			'none' 'first_order' 'second_order'
		    }
		    -widget optionmenu
		}                

		var remove_rigid_rot {
		    -label "Remove the total torque from internal forces (remove_rigid_rot):"
		    -widget    radiobox
		    -textvalue { Yes No }	      
		    -value     { .true. .false. }		
		}

		separator -label "--- Molecular Dynamics ---"

		group md {
		    var ion_temperature {
			-label    "Temperature of ions (ion_temperature):"
			-widget   optionmenu
			-textvalue {
			    "velocity rescaling via tempw&tolp  <rescaling>"
			    "velocity rescaling via tempw&nraise  <rescale-v>"
			    "velocity rescaling via delta_t  <rescale-T>"
			    "reduce ionic temperature via delta_t&nraise  <reduce-T>"
			    "\"soft\" Berendsen velocity rescaling via tempw&nraise  <berendsen>"
			    "use Andersen thermostat via tempw&nraise  <andersen>"
			    "not controlled  <not_controlled>"
			}
			-value {
			    'rescaling'
			    'rescale-v'
			    'rescale-T'
			    'reduce-T'
			    'berendsen'
			    'andersen'
			    'not_controlled'
			}
		    }
		    
		    var tempw {
			-label    "Starting temperature in MD runs (tempw):"
			-validate  fortrannonnegreal
		    }
		    
		    var tolp {
			-label    "Tolerance for velocity rescaling (tolp):"
			-validate fortranreal
		    }
                    
                    var delta_t {
			-label    "Temperature rescaling (delta_t):"
			-validate fortranreal
		    }
                    
                    var nraise {
			-label    "Rescaling interval (nraise):"
			-validate integer
		    }

		    #var monitor_constr {
		    #	-label "Only monitor (not impose) constraints (monitor_constr):"
		    #	-widget    radiobox
		    #	-textvalue { Yes No }	      
		    #	-value     { .true. .false. }
		    #}

		    var refold_pos {
			-label "Refolded ions at each step into the supercell (refold_pos):"
			-widget    radiobox
			-textvalue { Yes No }	      
			-value     { .true. .false. }
		    }
		}

		separator -label "--- BFGS Structural Optimization ---"

		var upscale {
		    -text    "Max. reduction factor for conv_thr during structural optimization"
		    -label   "Max. reduction factor (upscale):"
		    -validate  fortranposreal
		}

		group bfgs {
		    var bfgs_ndim {
			-label "Workspace dimension used in the PULAY mixing of the residual vectors:"
			-widget   spinint
			-validate posint
		    }

		    var trust_radius_max {
			-label "Maximum ionic displacement in the structural relaxation (trust_radius_max):"
			-validate fortranposreal
		    }

		    var trust_radius_min {
			-label "Minimum ionic displacement in the structural relaxation (trust_radius_min):"
			-validate fortranposreal
		    }

		    var trust_radius_ini {
			-label "Initial ionic displacement in the structural relaxation (trust_radius_ini):"
			-validate fortranposreal
		    }
		    
		    group w1_w2 -name "Parameters used in line search based on the Wolfe conditions:" -decor normal {
			packwidgets left
			var w_1 -label "w_1:" -validate fortranreal			
			var w_2 -label "w_2:" -validate fortranreal			
		    }
		}

		separator -label "--- Nudget Elastic Band (NEB) and String Method Dynamics (SMD) ---"
		
		group path {
		    var num_of_images {
			-label   "Number of images used to discretize the path (num_of_images):"
			-widget   spinint
			-validate posint
		    }
		    
		    var first_last_opt {
			-label "Optimize also the first and the last configurations (first_last_opt):"
			-textvalue { Yes No }
			-value     { .TRUE. .FALSE. }
			-widget    radiobox
		    }
		    		    
		    var opt_scheme {
			-label "Type of optimization scheme (opt_scheme):"
			-value {
			    'quick-min' 
                            'broyden'
			    'sd'
			    'langevin'
			}
			-textvalue {
			    "optimization algorithm based on molecular dynamics  <quick-min>"
                            "second Broyden method  <broyden>"
			    "steepest descent  <sd>"
			    "finite temperature langevin dynamics  <langevin>"
			}
			-widget optionmenu
		    }

		    #var damp {
		    #	-label    "Damping coefficent for damped-dyn (damp):"
		    #	-validate fortranreal
		    #}
		    
		    var temp_req {
			-label    "Temperature used for langevin dynamics of the string (temp_req):"
			-validate fortranposreal
		    }

		    var ds {
			-label    "Optimization step length (ds):"
			-validate fortranposreal
		    }
		    
		    var path_thr {
			-label "Convergence threshold for path optimization (path_thr):"
			-validate fortranposreal
		    }
                    
                    var use_freezing {
			-label "Only the images with larger errors are optimised (use_freezing):"
			-textvalue { Yes No }
			-value     { .TRUE. .FALSE. }
			-widget    radiobox
		    }

                    var use_masses {
			-label "The optimisation is done with mass-weighted coordinates (use_masses):"
			-textvalue { Yes No }
			-value     { .TRUE. .FALSE. }
			-widget    radiobox
		    }

		    #var write_save {
		    #	-label "Write a prefix.save file for each image (write_save):"
		    #	-textvalue { Yes No }
		    #	-value     { .TRUE. .FALSE. }
		    #	-widget    radiobox
		    #}
                                        
		}
                
                group neb {
              
		    var CI_scheme {
			-label "Type of Climbing Image (CI) scheme (CI_scheme):"
			-textvalue {
			    "do not use climbing image  <no-CI>"
			    "image highest in energy is allowed to climb  <auto>"
			    "climbing images are manually selected  <manual>"
			}
			-value {
			    'no-CI'
			    'auto'
			    'manual'
			}
			-widget optionmenu
		    }
              
		    group elastic_constants -name "Elastic Constants for NEB spring:" -decor normal {
			packwidgets left
			var k_max -label "k_max:" -validate fortranposreal			
			var k_min -label "k_min:" -validate fortranposreal			
		    }
              
                }
                
                #group smd {
                #
                #    #var use_fourier {
		#    #	-label "The path is described by its Fourier components (use_fourier):"
		#    #	-textvalue { Yes No }
		#    #	-value     { .TRUE. .FALSE. }
		#    #	-widget    radiobox
		#    #}
		#    
		#    #var use_multistep {
		#    #	-label "Images are sequentially added to the path (use_multistep):"
		#    #	-textvalue { Yes No }
		#    #	-value     { .TRUE. .FALSE. }
		#    #	-widget    radiobox
		#    #}
                #    #
		#    #
		#    #var free_energy {
		#    #	-label "Evalute the free-energy profile (free_energy):"
		#    #	-textvalue { Yes No }
		#    #	-value     { .TRUE. .FALSE. }
		#    #	-widget    radiobox
		#    #}
		#
		#}

		separator -label "--- Meta-Dynamics ---"

		group metadyn {		    
		    auxilvar n_fe_step {
			-label    "How many meta-dynamics step lengths (howmany_fe_steps):"
			-widget   spinint
			-validate posint
			-default 1
		    }
		    dimension fe_step {
			-label "Meta-dynamics step length (fe_step):"
			-start 1 -end 1
			-validate fortranreal
		    }

		    var g_amplitude {
			-label "Amplitude of the gaussians used in meta-dinamics (g_amplitude):"
			-validate fortranreal
		    }
                
  		    #var g_sigma {
		    #	-label "Spread of the gaussians used in meta-dinamics (g_sigma):"
		    #	-validate fortranreal
		    #}

		    var fe_nstep {
			-label "Max. \# of steps to evaluate the potential of mean force (fe_nstep):"
			-widget spinint
			-validate posint
		    }

		    var sw_nstep {
		    	-label "Number of steps used to switch to the new values\nof the collective variables (sw_nstep):"
		    	-widget spinint
		    	-validate nonnegint
		    }
		    
		    #var shake_nstep {
		    #	-label "Max. \# of steps to \"shake\" the collective variables (shake_nstep):"
		    #	-widget spinint
		    #	-validate posint
		    #}
		}
	    }
	}
    }


    ########################################################################
    ##                                                                    ##
    ##                      &CELL NAMELIST                                ##
    ##                                                                    ##
    ########################################################################

    page variableCellPage -name "Variable Cell" {

	namelist cell -name "CELL" {
	    var cell_dynamics {
		-label "Type of dynamics for the cell (cell_dynamics):"
		-textvalue {
		    "None  <none>"
		    "Damped (Beeman) dynamics of the Parrinello-Raman extended lagrangian  <damp-pr>"
		    "Damped (Beeman) dynamics of the new Wentzcovitch extended lagrangian  <damp-w>"
		    "BFGS quasi-newton algorithm (ion_dynamics must be 'bfgs' too)  <bfgs>"
		    "(Beeman) dynamics of the Parrinello-Raman extended lagrangian  <pr>"
		    "(Beeman) dynamics of the new Wentzcovitch extended lagrangian  <w>"
		}	    
		-value {
		    'none'
		    'damp-pr'
		    'damp-w'
		    'bfgs'
		    'pr'
		    'w'
		}
		-widget optionmenu
	    }
	    
	    var press {
		-label    "Target pressure \[in KBar\] in a variable-cell MD (press):"
		-validate  fortranreal
	    }
	    
	    var wmass {
		-label    "Ficticious cell mass for variable-cell MD (wmass):"
		-validate  fortranreal

	    }
	    
	    var press_conv_thr {
		-label     "Convergence pressure threshold \[in KBar\] (press_conv_thr):"
		-validate  fortranposreal
	    }
	    
	    var cell_factor {
		-text     "This variable is used in the construction of the pseudopotential tables. It should exceed the maximum linear contraction of the cell during a simulation"
		-label    "Cell factor (cell_factor):"
		-validate  fortranreal
	    }

	    var cell_dofree {
		-label "Which of the cell parameters should be moved (cell_dofree):"
		-textvalue {
		    "all     = all axis and angles are propagated"
		    "volume  = the cell is simply rescaled, without changing the shape"
		    "x       = only the x axis is moved"
		    "y       = only the y axis is moved"
		    "z       = only the z axis is moved"
		    "xy      = only the x and y axis are moved, angles are unchanged"
		    "xz      = only the x and z axis are moved, angles are unchanged"
		    "yz      = only the y and z axis are moved, angles are unchanged"
		    "xyz     = x, y and z axis are moved, angles are unchanged"
		    "xyt     = x1, x2, y2 (i.e. lower xy triangle of the 2 vectors)"
		    "xys     = x1, y1, x2, y2 (i.e. xy square of the 2 vectors)"
		    "xyzt    = x1, x2, y2, x3, y3, z3 (i.e. lower xyz triangle of the 3 vectors)"
		}	    
		-value {
		    'all' 'volume' 'x' 'y' 'z' 'xy' 'xz' 'yz' 'xyz' 'xyt' 'xys' 'xyzt'  
		}
		-widget optionmenu
	    }
	}
    }

    ########################################################################
    ##                                                                    ##
    ##                      &PHONON NAMELIST                              ##
    ##                                                                    ##
    ########################################################################

    page phononPage -name "Phonon" {
	namelist phonon -name "PHONON" {
	    var modenum {
		-label    "Mode number for single-mode phonon calculation (modenum):"
		-widget   spinint
		-validate posint
		-fmt      %d
	    }
	    
	    #packwidgets left
	    dimension xqq {
		-label    "q-point \[in 2pi/a units\] for phonon calculation"
		-validate  fortranreal
		-start    1
		-end      3
		-pack     left
	    }
	}
    }


    ########################################################################
    ##                                                                    ##
    ##                      &PHONON NAMELIST                              ##
    ##                                                                    ##
    ########################################################################

    page eePage -name "EE" {
	namelist ee -name "EE" {

	    var which_compensation { 
		-label "Correction for electrostatic environment (which_compensation):"
		-widget optionmenu
		-textvalue { 
		    {None <none>}
		    {Density counter charge correction <dcc>}
		}
		-value {'none' 'dcc'}
	    }

	    var ecutcoarse {
		-validate fortranposreal 
		-label "Kinetic energy cutoff for the open boundary (ecutcoarse):"
	    }
        

	    var mixing_charge_compensation {
		-validate fortranreal 
		-label "Scf mixing parameter for the correcting potential (mixing_charge_compensation):"
            }        

	    var n_charge_compensation {
		-validate posint
		-label "Iteration interval for updating the correcting potential (n_charge_compensation):"
	    }

	    var comp_thr {
		-validate fortranposreal
		-label "Scf convergence treshold for starting the dcc correction (comp_thr):"
	    }

	    var nlev {
		-validate posint
		-label "Number of depth levels used by the multigrid solver (nlev):"
            }
        }
    }	        


    ########################################################################
    ##                                                                    ##
    ##     CARDS: CELL_PARAMETERS, ATOMIC_SPECIES, ATOMIC_POSITIONS       ##
    ##                                                                    ##
    ########################################################################

    page latticeAtomdataPage -name "Lattice & Atomic data" {

	#
	# CELL_PARAMETERS
	#
	group cards__CELL_PARAMETERS {
	    line lattice_type_line -name "Lattice type" {
		keyword cell_parameters CELL_PARAMETERS
		var CELL_PARAMETERS_flags {
		    -label    "Lattice type:" 
		    -value    {cubic hexagonal}
		    -widget   radiobox
		    -default  cubic
		}
	    }
	    table lattice {
		-caption  "Enter Lattice Basis Vectors:"
		-head     {X-Component Y-Component Z-Component}
		-validate {fortranreal fortranreal fortranreal}
		-cols     3
		-rows     3
		-outfmt   {"  %14.9f" %14.9f %14.9f}
	    }	
	}

	#
	# ATOMIC_SPECIES
	#
	keyword atomic_species_key ATOMIC_SPECIES\n
	table atomic_species \
	    -caption  "Enter atomic types:" \
	    -head     {Atomic-label Atomic-Mass Pseudopotential-file} \
	    -cols     3 \
	    -rows     1 \
	    -outfmt   {"  %3s" %10.5f " %s"} \
	    -validate {whatever fortranreal whatever} \
	    -widgets  [list entry entry [list entrybutton "Pseudopotential ..." [list ::pwscf::pwSelectPseudopotential $this atomic_species]]]
	
	#
	# ATOMIC_POSITIONS
	#
	line atom_coor_unit -name "Atomic coordinate unit" {
	    keyword atomic_positions ATOMIC_POSITIONS
	    var ATOMIC_POSITIONS_flags {
		-label    "Atomic coordinate length unit:" 
		-textvalue {
		    "Cartesian in ALAT (i.e. in length units of celldm(1))  <alat>"
		    "Cartesian in BOHR  <bohr>"
		    "Cartesian in ANGSTROMS  <angstroms>"
		    "Internal crystal coordinates  <crystal>"
		}
		-value {alat bohr angstrom crystal}	    
		-widget radiobox
		-default "Cartesian in ALAT (i.e. in length units of celldm(1))  <alat>"
	    }
	}
		
	scriptvar old_path_inter_nimages
	auxilvar path_inter_nimages {
	    -label    "Number of intermediate images:"
	    -widget   spinint
	    -validate nonnegint
	    -default  0
	}
	
	# first_image
	
	keyword first_image first_image\n; # only for calculation == 'neb' || 'smd'
	table atomic_coordinates {
	    -caption   "Enter atomic coordinates:"
	    -head      {Atomic-label X-Coordinate Y-Coordinate Z-Coordinate if_pos(1) if_pos(2) if_pos(3)}
	    -validate  {string fortranreal fortranreal fortranreal binary binary binary}
	    -cols      7
	    -rows      1
	    -outfmt    {"  %3s" "  %14.9f" %14.9f %14.9f "  %2d" %2d %2d}
	    -widgets   {entry entry entry entry checkbutton}
	    -onvalues  1
	    -offvalues 0
	    -optionalcols 4
	}
	# -optcols   {4 5 6}

	loaddata atomic_coordinates ::pwscf::pwLoadAtomCoor \
	    "Load atomic coordinates from file ..."    

	# intermediate_image
	    
	# BEWARE: it is assumed that 50 intermediate images is the
	# largest allowed number (this is dirty)
	    	
	for {set i 1} {$i <= 50} {incr i} {
	    keyword intermediate_image_$i intermediate_image\n
	    table atomic_coordinates_${i}_inter [subst {
		-caption   "Enter atomic coordinates for INTERMEDIATE image \#.$i:"
		-head      {Atomic-label X-Coordinate Y-Coordinate Z-Coordinate}
		-validate  {string fortranreal fortranreal fortranreal}
		-cols      4
		-rows      1
		-outfmt    {"  %3s" "  %14.9f" %14.9f %14.9f}
		-widgets   {entry entry entry entry}
		-onvalues  1
		-offvalues 0
	    }]
	    loaddata atomic_coordinates_${i}_inter [list ::pwscf::pwLoadAtomCoorInter $i] \
		"Load atomic coordinates from file ..."    
	}
	
	# last_image
	
	keyword last_image last_image\n
	table atomic_coordinates_last_image {
	    -caption   "Enter atomic coordinates for LAST image:"
	    -head      {Atomic-label X-Coordinate Y-Coordinate Z-Coordinate}
	    -validate  {string fortranreal fortranreal fortranreal}
	    -cols      4
	    -rows      1
	    -outfmt    {"  %3s" "  %14.9f" %14.9f %14.9f}
	    -widgets   {entry entry entry entry}
	    -onvalues  1
	    -offvalues 0
	}
	loaddata atomic_coordinates_last_image ::pwscf::pwLoadAtomCoorLast \
	    "Load atomic coordinates from file ..."    
    }    


    ########################################################################
    ##                                                                    ##
    ##                         CARD: K_POINTS                             ##
    ##                                                                    ##
    ########################################################################

    page kpointsPage -name "K-point data" {
	#
	# K_POINTS
	#
	line kpoint_type_line -name "K-points type" {
	    keyword k_points K_POINTS
	    var K_POINTS_flags {
		-label    "K-Point input" 
		-textvalue {
		    "Manual specification in 2pi/a units  <tpiba>"
		    "Manual specification in CRYSTAL units  <crystal>"
		    "Automatic generation  <automatic>"
		    "Gamma point only  <gamma>"
		    "Manual \"2pi/a\" specification for band structure plot <tpiba_b>"
		    "Manual \"crystal\" specification for band structure plot <crystal_b>"
		}
		-value {
		    tpiba crystal automatic gamma tpiba_b crystal_b
		}
		-widget radiobox
		-default "Manual specification in 2pi/a units  <tpiba>"
	    }
	}

	line nks_line -name "Number of K-points" {
	    var nks -label "Number of K-points:" -widget spinint -validate posint -default 1
	}

	# if nks=0 then enter the mesh and shifts
	line kmesh_line -name "K-point mesh + shift" {
	    group kmesh -name Kmesh {
		packwidgets left
		var nk1 -label "nk1:"  -widget spinint  -validate posint  -outfmt "  %d "  -default 1
		var nk2 -label "nk2:"  -widget spinint  -validate posint  -outfmt "%d "  -default 1
		var nk3 -label "nk3:"  -widget spinint  -validate posint  -outfmt "%d "  -default 1
	    }
	    group kshift -name Kshift {
		packwidgets left
		var sk1 -label "sk1:"  -widget spinint  -validate binary  -outfmt "  %d "  -default 1
		var sk2 -label "sk2:"  -widget spinint  -validate binary  -outfmt "%d "  -default 1
		var sk3 -label "sk3:"  -widget spinint  -validate binary  -outfmt "%d "  -default 1
	    }
	}

	# elseif nks>0 enetr kpoint coordinates
	table kpoints {
	    -caption  "Enter the coordinates of the K-points below:"
	    -head     {KX-Coordinate KY-Coordinate KZ-Coordinate Weight}
	    -cols     4
	    -rows     0
	    -validate {fortranreal fortranreal fortranreal fortranreal}
	    -outfmt   {%14.9f %14.9f %14.9f "  %14.9f"}
	}
	loaddata kpoints ::pwscf::pwLoadKPoints \
	    "Load K-point coordinates from file ..."	
    }

    ########################################################################
    ##                                                                    ##
    ##         PAGE: CLIMBING_IMAGES & CONSTRAINTS & OCCUPATIONS          ##
    ##                                                                    ##
    ########################################################################
    page otherPage -name "Other Cards" {

	# CARD: CLIMBING_IMAGES

	group climbing_images -name "Card: CLIMBING_IMAGES" -decor normal {
	    keyword climbing_images_key CLIMBING_IMAGES\n
	    line climbing_images_line -decor none {
		var climbing_images_list {
		    -label "List of climbing images, separated by a comma:"
		    -infmt %S
		}
	    }
	}

	# CARD: CONSTRAINTS
	
	group constraints_group -name "Card: CONSTRAINTS" -decor normal {

	    auxilvar constraints_enable {
		-label     "Use constraints:"
		-value     {Yes No}
		-widget    radiobox
		-default   No
	    }

	    group constraints_card -decor none {

		keyword constraints_key CONSTRAINTS\n

		line constraints_line1 -decor none {
		    var nconstr {
			-label    "Number of constraints:"		    
			-validate posint
			-widget   spinint
			-default  1
			-outfmt   "  %d "
		    }
		    var constr_tol {
			-label    "Tolerance for keeping the constraints satisfied:"
			-validate fortranposreal
		    }
		}

		table constraints_table {
		    -caption  "Enter constraints data:\n    constraint-type   constr(1,.)   constr(2,.)   ...   { constr_target(.) }\n\n(see Help for the format of \"constraint-specification\")"
		    -head     {constraint-type constraint-specifications ... ... ... ...}
		    -validate {string fortranreal}
		    -cols     6
		    -rows     1
		    -optionalcols 3
		    -widgets  {{optionmenu {'type_coord' 'atom_coord' 'distance' 'planar_angle' 'torsional_angle' 'bennett_proj'}} entry}
		    -outfmt   {"  %s  " %S}
		    -infmt    {%d %S}
		}
		#scriptvar old_nconstr
		#for {set i 1} {$i <= 50} {incr i} {	    
		#	line constraint.$i -decor none [subst { 		    
		#	    var constraint_type.$i {
		#		-label "Type of constraint:"
		#		-widget optionmenu
		#		-value {
		#		    'type_coord'      
		#		    'atom_coord'      
		#		    'distance'        
		#		    'planar_angle'    
		#		    'torsional_angle' 
		#		    'bennett_proj'    
		#		}
		#	    }
		#	    
		#	    packwidgets left		    
		#	    var constr.${i}_1 -label "constr(1,$i):" -validate fortranreal
		#	    var constr.${i}_2 -label "constr(2,$i):" -validate fortranreal
		#	    var constr.${i}_3 -label "constr(3,$i):" -validate fortranreal
		#	    var constr.${i}_4 -label "constr(4,$i):" -validate fortranreal
		#	    
		#	    packwidgets bottom		    
		#	    var constr_target_$i {
		#		-label "Target for the constrain:"
		#		-validate fortranreal
		#	    }
		#	}]
		#}	    
	    }
	}    
	
	# CARD: COLLECTIVE_VARS

	group collective_vars_group -name "Card: COLLECTIVE_VARS" -decor normal {
	    
	    auxilvar collective_vars_enable {
		-label     "Use collective variables:"
		-value     {Yes No}
		-widget    radiobox
		-default   No
	    }
	    
	    group collective_vars_card -decor none {

		keyword collective_vars COLLECTIVE_VARS\n

		line collective_vars_line1 -decor none {
		    var ncolvar {
			-label    "Number of collective variables:"
			-validate posint
			-widget   spinint
			-default  1
			-outfmt   "  %d "
		    }
		    var colvar_tol {
			-label    "Tolerance for keeping the collective variables satisfied:"
			-validate fortranposreal
		    }
		}
		
		table collective_vars_table {
		    -caption  "Enter data for collective variables:\n    colvar-type   colvar(1,.)   colvar(2,.)   ...  \n\n(see the definition of constr in the CONSTRAINTS card.)"
		    -head     {colvar-type colvar-specifications ... ... ... ...}
		    -validate {string fortranreal}
		    -cols     6
		    -rows     1
		    -optionalcols 3
		    -widgets  {{optionmenu {'type_coord' 'atom_coord' 'distance' 'planar_angle' 'torsional_angle' 'bennett_proj'}} entry}
		    -outfmt   {"  %s  " %S}
		    -infmt    {%d %S}
		}
	    }
	}

	# CARD: OCCUPATIONS
	
	group occupations_card -name "Card: OCCUPATIONS" -decor normal {	    
	    keyword occupations_key OCCUPATIONS\n
	    text occupations_table \
		-caption "Syntax for NON-spin polarized case:\n     u(1)  ....   ....   ....  u(10)\n     u(11) .... u(nbnd)\n\nSyntax for spin-polarized case:\n     u(1)  ....   ....   ....  u(10)\n     u(11) .... u(nbnd)\n     d(1)   ....  ....   ....  d(10)\n     d(11) .... d(nbnd)" \
		-label   "Specify occupation of each state (from 1 to nbnd) such that 10 occupations per are written per line:" \
		-readvar ::pwscf::pwscf($this,OCCUPATIONS)
	}
    }
    

    # ----------------------------------------------------------------------
    # take care of specialities
    # ----------------------------------------------------------------------
    source pw-event.tcl

    # ------------------------------------------------------------------------
    # source the HELP file
    # ------------------------------------------------------------------------
    source pw-help.tcl
}
